========================================
History
========================================

1.1.0(2017-05-30)
----------------------------------------

* Add chunking feature
* Add pos_tag feature
* Add word_sent feature, fix performance
* Add Corpus class
* Add Transformer classes
* Integrated with dictionary of Ho Ngoc Duc
* Add travis-CI, auto build with PyPI

1.0.0 (2017-03-01)
----------------------------------------

* First release on PyPI.
* First release on Readthedocs
